armyknife_time library

Classes

Clock
IClock is intended for use anywhere you need to have access to the current time. Although it's not strictly incorrect to call SystemClock.Instance.GetCurrentInstant() directly, in the same way as you might call DateTime.UtcNow, it's strongly discouraged as a matter of style for production code. We recommend providing an instance of IClock to anything that needs it, which allows you to write tests using the fake clock in the TimeMachine.Testing assembly (or your own implementation).
ClockDelegate
Clock のDelegateオブジェクト. 指定した処理のみを行い、他の処理は元のClockに委譲する.
Instant
Represents an instant on the global timeline, with nanosecond resolution.
InstantX
Time
Represents a fixed (and calendar-independent) length of time.