IClock is intended for use anywhere you need to have access to the current time.
Although it's not strictly incorrect to call SystemClock.Instance.GetCurrentInstant() directly,
in the same way as you might call DateTime.UtcNow, it's strongly discouraged
as a matter of style for production code. We recommend providing an instance of IClock
to anything that needs it, which allows you to write tests using the fake clock in the TimeMachine.Testing
assembly (or your own implementation).